// This file is generated by kconfig_compiler_kf5 from libkcddb5.kcfg.
// All changes you do to this file will be lost.
#ifndef CONFIGBASE_H
#define CONFIGBASE_H

#include "kcddb_export.h"

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

#include <QDir>

class ConfigBasePrivate;

class KCDDB_EXPORT ConfigBase : public KConfigSkeleton
{
  public:
    class EnumFreedbLookupTransport
    {
      public:
      enum type { CDDBP, HTTP, COUNT };
    };
    class EnumFreedbSubmitTransport
    {
      public:
      enum type { HTTP, SMTP, COUNT };
    };

    ConfigBase( );
    ~ConfigBase() override;

    /**
      Set hostname
    */
    void setHostname( const QString & v );

    /**
      Get hostname
    */
    QString hostname() const;

    /**
      Is hostname Immutable
    */
    bool isHostnameImmutable() const;

    /**
      Set port
    */
    void setPort( int v );

    /**
      Get port
    */
    int port() const;

    /**
      Is port Immutable
    */
    bool isPortImmutable() const;

    /**
      Set MusicBrainzLookupEnabled
    */
    void setMusicBrainzLookupEnabled( bool v );

    /**
      Get MusicBrainzLookupEnabled
    */
    bool musicBrainzLookupEnabled() const;

    /**
      Is MusicBrainzLookupEnabled Immutable
    */
    bool isMusicBrainzLookupEnabledImmutable() const;

    /**
      Set FreedbLookupEnabled
    */
    void setFreedbLookupEnabled( bool v );

    /**
      Get FreedbLookupEnabled
    */
    bool freedbLookupEnabled() const;

    /**
      Is FreedbLookupEnabled Immutable
    */
    bool isFreedbLookupEnabledImmutable() const;

    /**
      Set CacheLookupEnabled
    */
    void setCacheLookupEnabled( bool v );

    /**
      Get CacheLookupEnabled
    */
    bool cacheLookupEnabled() const;

    /**
      Is CacheLookupEnabled Immutable
    */
    bool isCacheLookupEnabledImmutable() const;

    /**
      Set FreedbLookupTransport
    */
    void setFreedbLookupTransport( int v );

    /**
      Get FreedbLookupTransport
    */
    int freedbLookupTransport() const;

    /**
      Is FreedbLookupTransport Immutable
    */
    bool isFreedbLookupTransportImmutable() const;

    /**
      Set cacheLocations
    */
    void setCacheLocations( const QStringList & v );

    /**
      Get cacheLocations
    */
    QStringList cacheLocations() const;

    /**
      Is cacheLocations Immutable
    */
    bool isCacheLocationsImmutable() const;

    /**
      Set FreedbSubmitTransport
    */
    void setFreedbSubmitTransport( int v );

    /**
      Get FreedbSubmitTransport
    */
    int freedbSubmitTransport() const;

    /**
      Is FreedbSubmitTransport Immutable
    */
    bool isFreedbSubmitTransportImmutable() const;

    /**
      Set emailAddress
    */
    void setEmailAddress( const QString & v );

    /**
      Get emailAddress
    */
    QString emailAddress() const;

    /**
      Is emailAddress Immutable
    */
    bool isEmailAddressImmutable() const;

    /**
      Set httpSubmitServer
    */
    void setHttpSubmitServer( const QString & v );

    /**
      Get httpSubmitServer
    */
    QString httpSubmitServer() const;

    /**
      Is httpSubmitServer Immutable
    */
    bool isHttpSubmitServerImmutable() const;

    /**
      Set httpSubmitPort
    */
    void setHttpSubmitPort( int v );

    /**
      Get httpSubmitPort
    */
    int httpSubmitPort() const;

    /**
      Is httpSubmitPort Immutable
    */
    bool isHttpSubmitPortImmutable() const;

    /**
      Set smtpPort
    */
    void setSmtpPort( int v );

    /**
      Get smtpPort
    */
    int smtpPort() const;

    /**
      Is smtpPort Immutable
    */
    bool isSmtpPortImmutable() const;

    /**
      Set smtpUsername
    */
    void setSmtpUsername( const QString & v );

    /**
      Get smtpUsername
    */
    QString smtpUsername() const;

    /**
      Is smtpUsername Immutable
    */
    bool isSmtpUsernameImmutable() const;

    /**
      Set useGlobalEmail
    */
    void setUseGlobalEmail( bool v );

    /**
      Get useGlobalEmail
    */
    bool useGlobalEmail() const;

    /**
      Is useGlobalEmail Immutable
    */
    bool isUseGlobalEmailImmutable() const;

    /**
      Set replyTo
    */
    void setReplyTo( const QString & v );

    /**
      Get replyTo
    */
    QString replyTo() const;

    /**
      Is replyTo Immutable
    */
    bool isReplyToImmutable() const;

    /**
      Set smtpHostname
    */
    void setSmtpHostname( const QString & v );

    /**
      Get smtpHostname
    */
    QString smtpHostname() const;

    /**
      Is smtpHostname Immutable
    */
    bool isSmtpHostnameImmutable() const;

    /**
      Set submitAddress
    */
    void setSubmitAddress( const QString & v );

    /**
      Get submitAddress
    */
    QString submitAddress() const;

    /**
      Is submitAddress Immutable
    */
    bool isSubmitAddressImmutable() const;

  protected:
  private:
    ConfigBasePrivate *d;
};

#endif

